.. image:: https://img.shields.io/circleci/project/github/constructpm/pysyncgateway/master.svg
    :alt: CircleCI
    :target: https://circleci.com/gh/constructpm/pysyncgateway/tree/master

.. image:: https://img.shields.io/readthedocs/pysyncgateway.svg
    :alt: Read the Docs
    :target: https://pysyncgateway.readthedocs.io/

.. image:: https://img.shields.io/pypi/v/pysyncgateway.svg
    :alt: PyPI 
    :target: https://pypi.org/project/pysyncgateway/

.. image:: https://img.shields.io/pypi/pyversions/pysyncgateway.svg
    :alt: PyPI - Python Version
    :target: https://pypi.org/project/pysyncgateway/

.. image:: https://img.shields.io/github/license/constructpm/pysyncgateway.svg
    :alt: pysyncgateway is licensed under the Apache License 2.0
    :target: https://github.com/constructpm/pysyncgateway/blob/master/LICENSE


pysyncgateway
=============

Basic object orientated library for communicating with `Couchbase Sync Gateway
<https://github.com/couchbase/sync_gateway/)>`_, primarily through the admin
port.

Resources
---------

* `Documentation on ReadTheDocs <https://pysyncgateway.readthedocs.io/>`_

* `Package on PyPI <https://pypi.org/project/pysyncgateway/>`_

* `Source code on GitHub <https://github.com/constructpm/pysyncgateway>`_

* `Licensed on Apache License 2.0 <https://github.com/constructpm/pysyncgateway/blob/master/LICENSE>`_

* `Changelog <https://github.com/constructpm/pysyncgateway/blob/master/CHANGELOG.rst>`_

Tested against Pythons 2.7 and `3.5 (WIP)
<https://github.com/constructpm/pysyncgateway/issues/23>`_; Sync Gateway 1.5
community edition (walrus mode).
